@@ -63,4 +63,13 @@
 2023.1.5 1.0.8.3版本
     --- 新增 styles 皮肤包项目 
     --- 全面兼容 PyQt5,PyQt6,PySide2,PySide6, PySide6 在使用无边框的还有小问题
+2023.1.7 1.0.9.3版本
+    --- 新增流式布局(FlowLayout)
+    --- 互补色样式(contrastStyle())，同色调样式(homologyStyle())
+    --- 修复 标题栏和状态栏 无法绘制文字的BUG
+2023.1.8 1.0.9.4版本
+    --- 修复流式布局 在mac的间距问题
+    --- 优化 标题栏 和 状态栏 的代码
+    --- 优化获取文字大小函数 textSize() 对丢失像素进行补偿
+    --- 优化标题栏 在PyQt6,PySide6,标题高度计算不精准的Bug
 '''
\ No newline at end of file
